==> SyL-0.13.0.tar.gz: SyL/opt/setup/lib/CreateAction.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: CreateAction.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * եݡͥȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: CreateAction.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class CreateAction
{
    /**
     * ե
     *
     * @access public
     * @param string ץȥǥ쥯ȥ
     * @param string ץꥱ̾
     * @param string ե
     */
    function trigger($project_dir, $app_name, $action_file)
    {
        $action_dir = "{$project_dir}app/{$app_name}/actions/";
        if (!is_dir($action_dir)) {
            echo "  creating directory {$action_dir}\n"; ob_flush();
            if (!mkdir($action_dir, 0755)) {
                trigger_error("[SyL error] action directory can't create ({$action_dir})", E_USER_ERROR);
                exit;
            }
        }

        if (file_exists("{$project_dir}var/skel-templates/action.php")) {
            $action_template = "{$project_dir}var/skel-templates/action.php";
        } else {
            $action_template = SYL_PROJECT_DIR . '/var/skel-templates/action.php';
        }
        $contents = file_get_contents($action_template);

        if (!is_array($action_file)) {
            $action_file = array($action_file);
        }

        for ($i=0; $i<count($action_file); $i++) {
            if (preg_match('/^(\\\\|\/)/', $action_file[$i])) {
                $action_file[$i] = '/' . substr($action_file[$i], 1);
            }

            // 饹̾Ѵ
            $class_name = implode('_', array_map('ucfirst', preg_split('/(\\\\|\/)/', $action_file[$i])));
            $trans = array(
              '{SYL_CLASS}' => $class_name,
              '{APP_NAME}'  => $app_name
            );
            $contents_tmp = strtr($contents, $trans);

            $file = $action_dir . ucfirst($action_file[$i]) . '.php';
            $tmp = dirname($file) . '/';
            $create_dir = array();
            while (preg_match('/^' . preg_quote($action_dir, '/') . '/', $tmp)) {
                array_unshift($create_dir, $tmp);
                $tmp = dirname($tmp);
            }

            foreach ($create_dir as $dir) {
                if (!is_dir($dir)) {
                    echo "  creating directory {$dir}\n"; ob_flush();
                    mkdir($dir, 0755);
                }
            }

            echo "  creating file {$file}\n"; ob_flush();
            $fp = fopen($file, 'wb');
            fwrite($fp, $contents_tmp);
            fclose($fp);
        }
    }
}

?>

==> SyL-0.14.2.tar.gz: SyL/opt/setup/lib/CreateAction.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: CreateAction.php,v 1.2 2007/08/27 06:00:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * եݡͥȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: CreateAction.php,v 1.2 2007/08/27 06:00:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class CreateAction
{
    /**
     * ե
     *
     * @access public
     * @param string ץȥǥ쥯ȥ
     * @param string ץꥱ̾
     * @param string ե
     */
    function trigger($project_dir, $app_name, $action_file)
    {
        $action_dir = "{$project_dir}apps/{$app_name}/actions/";
        if (!is_dir($action_dir)) {
            echo "  creating directory {$action_dir}\n"; ob_flush();
            if (!mkdir($action_dir, 0755)) {
                trigger_error("[SyL error] action directory can't create ({$action_dir})", E_USER_ERROR);
                exit;
            }
        }

        if (file_exists("{$project_dir}var/skel-templates/action.php")) {
            $action_template = "{$project_dir}var/skel-templates/action.php";
        } else {
            $action_template = SYL_PROJECT_DIR . '/var/skel-templates/action.php';
        }
        $contents = file_get_contents($action_template);

        if (!is_array($action_file)) {
            $action_file = array($action_file);
        }

        for ($i=0; $i<count($action_file); $i++) {
            if (preg_match('/^(\\\\|\/)/', $action_file[$i])) {
                $action_file[$i] = '/' . substr($action_file[$i], 1);
            }

            // 饹̾Ѵ
            $class_name = implode('_', array_map('ucfirst', preg_split('/(\\\\|\/)/', $action_file[$i])));
            $trans = array(
              '{SYL_CLASS}' => $class_name,
              '{APP_NAME}'  => $app_name
            );
            $contents_tmp = strtr($contents, $trans);

            $file = $action_dir . ucfirst($action_file[$i]) . '.php';
            $tmp = dirname($file) . '/';
            $create_dir = array();
            while (preg_match('/^' . preg_quote($action_dir, '/') . '/', $tmp)) {
                array_unshift($create_dir, $tmp);
                $tmp = dirname($tmp);
            }

            foreach ($create_dir as $dir) {
                if (!is_dir($dir)) {
                    echo "  creating directory {$dir}\n"; ob_flush();
                    mkdir($dir, 0755);
                }
            }

            echo "  creating file {$file}\n"; ob_flush();
            $fp = fopen($file, 'wb');
            fwrite($fp, $contents_tmp);
            fclose($fp);
        }
    }
}

?>
